@@ -15,14 +15,22 @@ class Configuration:
     type_id: 'Optional[str]'
 
 
-def env(var: str, default: 'Optional[str]' = None) -> str:
+def optenv(var: str) -> 'Optional[str]':
     val = os.getenv(var)
 
-    LOG.debug('Configuration environment lookup: %r => %r (default: %r)', var, val, default)
+    LOG.debug('Configuration environment lookup: %r => %r', var, val)
+
+    return val
+
+
+def env(var: str, default: 'Optional[str]' = None) -> str:
+    val = optenv(var)
 
     if val:
         return val
     elif default:
+        LOG.debug('Using default %r for unspecified configuration environment variable: %r',
+                  default, var)
         return default
     else:
         raise Exception(f'Missing required environment variable: {var}')
@@ -43,8 +51,8 @@ def get_default_config() -> 'Configuration':
         ledger_url=env('DABL_LEDGER_URL', 'http://localhost:6865'),
         ledger_id=env('DABL_LEDGER_ID', 'cloudbox'),
         integration_metadata_path=env('DABL_INTEGRATION_METADATA_PATH', 'int_args.yaml'),
-        integration_id=os.getenv('DABL_INTEGRATION_INTEGRATION_ID'),
-        type_id=os.getenv('DABL_INTEGRATION_TYPE_ID'))
+        integration_id=optenv('DABL_INTEGRATION_INTEGRATION_ID'),
+        type_id=optenv('DABL_INTEGRATION_TYPE_ID'))
 
     LOG.info('Configuration: %r', asdict(config))
 
